@@ -17,6 +17,8 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <ncurses.h>
 #include <locale.h>
 #include <sys/types.h>
@@ -41,7 +43,7 @@ char homedir[256];
 struct conf config;
 double size_gtk;
 GtkWidget *size_msg, *scroll_win, *filelist, *fileselect, *toolbar, *radio_frame, *radio_vbox, *info[3];
-static gint index=-1;
+static gint rowindex=-1;
 gchar *selectedFile=NULL;
 
 /*** LABELS ***/
@@ -145,12 +147,14 @@ gboolean help_win_gtk(GtkWidget *widget, gpointer user_data)
     gtk_text_buffer_insert_at_cursor(buffer, "Copyright (c) 2002-2004 Balazs Varkonyi\n", -1);
     gtk_text_buffer_insert_at_cursor(buffer, "\n", -1);
     gtk_text_buffer_insert_at_cursor(buffer, "  Authors:\n", -1);
-    gtk_text_buffer_insert_at_cursor(buffer, "  * Balazs Varkonyi\n", -1);
-    gtk_text_buffer_insert_at_cursor(buffer, "  * Csaba Feher\n", -1);
-    gtk_text_buffer_insert_at_cursor(buffer, "  * Sebastian Henschel\n", -1);
-    gtk_text_buffer_insert_at_cursor(buffer, "  * Miklos Honti\n", -1);
-    gtk_text_buffer_insert_at_cursor(buffer, "  * Marcel Hilzinger\n", -1);
-    gtk_text_buffer_insert_at_cursor(buffer, "  * Jesus Espino\n", -1);
+    gtk_text_buffer_insert_at_cursor(buffer, "  * Balazs Varkonyi <vbali@linuxforge.hu>\n", -1);
+    gtk_text_buffer_insert_at_cursor(buffer, "  * Csaba Feher <linuxfan@nrg.hu>\n", -1);
+    gtk_text_buffer_insert_at_cursor(buffer, "\n", -1);
+    gtk_text_buffer_insert_at_cursor(buffer, "  Special thanks to:\n", -1);
+    gtk_text_buffer_insert_at_cursor(buffer, "  * Laszlo Boszormenyi <gcs@debian.hu>\n", -1);
+    gtk_text_buffer_insert_at_cursor(buffer, "  * Sebastian Henschel <cdw@kodeaffe.de>\n", -1);
+    gtk_text_buffer_insert_at_cursor(buffer, "  * Marcel Hilzinger <hili@suselinux.hu>\n", -1);
+    gtk_text_buffer_insert_at_cursor(buffer, "  * Jesus Espino <jespino@gul.uc3m.es>\n", -1);
     gtk_text_buffer_insert_at_cursor(buffer, "\n", -1);
     gtk_text_buffer_insert_at_cursor(buffer, "  cdw is free software; you can redistribute it and/or\n", -1);
     gtk_text_buffer_insert_at_cursor(buffer, "  modify it under the terms of the GNU General Public License\n", -1);
@@ -927,8 +931,8 @@ gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
 
 void select_row_gtk(GtkCList *clist, gint row, gint column, GdkEventButton *event, gpointer user_data)
 {
-    index=row;
-    gtk_clist_get_text(GTK_CLIST(clist), index, 0, &selectedFile);
+    rowindex=row;
+    gtk_clist_get_text(GTK_CLIST(clist), rowindex, 0, &selectedFile);
 }
 
 
@@ -1186,12 +1190,12 @@ void delete_files_gtk(GtkWidget *widget, gpointer data)
     int c;
     char filetodelete[255]="\0";
     
-    if (index>=0){
+    if (rowindex>=0){
 	strcpy(filetodelete, homedir);
 	strcat(filetodelete,"/");
 	strcat(filetodelete, selectedFile);
 	unlink(filetodelete);
-	gtk_clist_remove(GTK_CLIST(filelist), index);
+	gtk_clist_remove(GTK_CLIST(filelist), rowindex);
 	select_window_gtk(FALSE);
     }
 }
@@ -1206,7 +1210,7 @@ double dirsize_gtk(char *dir)
     n = scandir(dir, &eps, (void *)one_gtk, alphasort);
     if (n>=0) {
 	for (cnt=0; cnt<n; ++cnt){
-    	    ch=(char *) malloc(strlen(eps[cnt]->d_name)+strlen(dir)+4,sizeof(char));
+    	    ch=(char *) malloc(strlen(eps[cnt]->d_name)+strlen(dir)+4+1);
 	    sprintf(ch,"%s/%s",dir,eps[cnt]->d_name);
 	    finfo=(struct stat *)malloc(sizeof(finfo)+100);
 	    ok=lstat(ch,finfo);
@@ -1271,7 +1275,7 @@ int select_window_gtk(bool real)
 	    }
 	    for (i=0; i<num; ++i) {
 		if ( cdfiles[i]->d_type!=DT_DIR ){
-		    ch=(char *) malloc(strlen(cdfiles[i]->d_name)+strlen(homedir)+4,sizeof(char));
+		    ch=(char *) malloc(strlen(cdfiles[i]->d_name)+strlen(homedir)+4+1);
 		    sprintf(ch,"%s/%s",homedir,cdfiles[i]->d_name);
 		    finfo=(struct stat *)malloc(sizeof(finfo)+100);
 		    ok=lstat(ch,finfo);
