@@ -17,11 +17,13 @@
  */
 
 #include <stdio.h>
+#include <string.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <ncurses.h>
 #include <nl_types.h>
 #include <form.h>
+#include <libintl.h>
 #include "options.h"
 #include "config.h"
 #include "color.h"
@@ -45,7 +47,7 @@ void clear_main_win()
 void write_conf(struct conf config)
 {
     FILE *conffile;
-    char home[256], opt[20], prop[256];
+    char home[256], opt[41], prop[256];
 
     sprintf(home,"%.225s/.cdw.conf", getenv("HOME"));
     if ( (conffile = fopen(home, "w")) != NULL ){
@@ -95,7 +97,7 @@ void write_conf(struct conf config)
 struct conf read_conf()
 {
     FILE *conffile;
-    char home[256], confhome[256], opt[20], prop[256];
+    char home[256], confhome[256], opt[41], prop[256];
     int line=0;
     
     sprintf(home,"%s", getenv("HOME"));
