@@ -17,6 +17,8 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 #include <pthread.h>
 #include <fcntl.h> 
@@ -27,6 +29,7 @@
 #include <regex.h>
 #include <nl_types.h>
 #include <time.h>
+#include <libintl.h>
 #include "options.h"
 #include "gettext.h"
 #include "isosize.h"
